function list = mergesegments(list, seconds);

%MERGESEGMENTS Merge (cluster) overlapping or nearby segments
%
% MERGESEGMENTS reads the requested segment list and merges segments which
% are separated by less than or equal to the specified number of seconds.
% The resulting segment list is returned.  The default separation of zero
% seconds merges all overlapping or adjacent segments.
%
%SYNOPSIS
%   OUT = mergesegments(IN, SECONDS);
%
%INPUTS
%   IN        input segment list
%   SECONDS   minimum segment separation
%
%OUTPUT
%   OUT       output segment list
%
% The segments list should be provided in the form of an N-by-2 matrix,
% formed from adjacent column-wise vectors of segment start and stop
% times.
%
%   start1 stop1
%   start2 stop2
%   start3 stop3
%    ...    ...
%   startN stopN
%
% By definition, a segment is the half closed interval [start,stop).
% A segment is inclusive of the specified start time, but exclusive of
% the specified stop time.  The duration of a segment is defined as the
% difference between stop and start times.
%
% As an alternative, each segment may also be specified by its start time
% and duration.  However, the resulting segment list will be returned in
% terms of start and stop times.
%
% MERGESEGMENTS also uses CULLSEGMENTS to remove zero length segments.
%
% See also NUMSEGMENTS, SORTSEGMENTS, and UNIQUESEGMENTS.
%
%AUTHOR
%   Shourov K. Chatterji (No longer part of the LV Collaboration)

% $Id: mergesegments.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% parse command line arguments
error(nargchk(1, 2, nargin));

% default minimum segment separation
if nargin == 1,
  seconds = 0;
end

% standardize segment list
list = stdsegments(list);

% remove zero length sequences
list = cullsegments(list);

% handle empty lists
if isempty(list),
  return;
end

% extract start and stop vectors
start = list(:,1);
stop = list(:,2);

% pad/trim segments
start = start - seconds / 2;
stop = stop + seconds / 2;

% label transitions
times = [start; stop;];
edges = [ones(size(start)); -ones(size(stop));];

% sort transitions
[times, indices] = sort(times);
edges = edges(indices);
edges = cumsum(edges);

% find merged segment boundaries
indices = find(edges == 0);
start = [times(1); times(indices(1:end-1) + 1);];
stop = times(indices);

% create return segment list
list = [start stop];

% remove zero length sequences
list = cullsegments(list);

% standardize segment list
list = stdsegments(list);

% return to calling function
return;
