function writesegments(list, file, format);

%WRITESEGMENTS Write list of segments to a file
%
% WRITESEGMENTS outputs the given segment list as two or three columns
% of whitespace delimited ASCII text to the specified file with one of
% the following formats.
%
%   start1 stop1          start1 stop1 length1
%   start2 stop2          start2 stop2 length2
%   start3 stop3    or    start3 stop3 length3
%    ...    ...            ...    ...    ...  
%   startN stopN          startN stopN lengthN
%
%SYNOPSIS
%   writesegments(LIST, FILE, FORMAT);
%
%INPUTS
%   LIST      segment list
%   FILE      filename to write to
%   FORMAT    'two', 'three', or 'full'
%
% If format is 'two', only the start and stop times will be written to
% the file.  If format is 'three', the start times, stop times, and
% segments durations will be written to the file.  If format is 'full',
% header information will be written to the file in addition to the
% three column output.  If no format is specified, the default is 'full'.
%
% WRITESEGMENTS prepends header lines to the beginning of the file which
% contains the file name, list name, author, date, and number of segments.
% Each header line begins with a '#' character to indicate it is a
% comment.
%
% The segments list should be provided in the form of an N-by-2 matrix,
% formed from adjacent column-wise vectors of segment start and stop
% times.
%
%   start1 stop1
%   start2 stop2
%   start3 stop3
%    ...    ...
%   startN stopN
%
% By definition, a segment is the half closed interval [start,stop).
% A segment is inclusive of the specified start time, but exclusive of
% the specified stop time.  The duration of a segment is defined as the
% difference between stop and start times.
%
% As an alternative, each segment may also be specified by its start time
% and duration.  However, the resulting segment list will be returned in
% terms of start and stop times.
%
% If the file already exists, it will be overwritten.
%
% See also LOADCONLOG, and LOADSEGMENTS.
%
%AUTHOR
%   Shourov K. Chatterji (No longer part of the LC Collaboration)

% $Id: writesegments.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% parse command line arguments
error(nargchk(2, 3, nargin));

% default format if none specified
if nargin == 2,
  format = 'full';
end

% standardize segment list
list = stdsegments(list);

% handle empty lists
if isempty(list),
  evalc(['!rm -f ' file]);
  evalc(['!touch ' file]);
  return;
end

% extract start and stop vectors
start = list(:,1);
stop = list(:,2);

% determine segment duration
duration = stop - start;

% open output file
[fid, fmessage] = fopen(file, 'w');
if fid == -1,
  error(fmessage)
end

% write header
if strcmp(format, 'full'),
  fprintf(fid, '# LIGO DATA SEGMENT LIST\n');
  fprintf(fid, '# ----------------------\n');
  fprintf(fid, '# \n');
  fprintf(fid, '# file:                %s\n', file);
  fprintf(fid, '# segment list:        %s\n', inputname(1));
  fprintf(fid, '# number of segments:  %d\n', length(start));
  fprintf(fid, '# created by:          %s@%s.%s\n', ...
          evalc('!/usr/bin/echo `whoami`\\c'), ...
          evalc('!/usr/bin/echo `hostname`\\c'), ...
          evalc('!/usr/bin/echo `domainname`\\c'));
  fprintf(fid, '# created on:          %s\n', datestr(now));
  fprintf(fid, '# \n');
  fprintf(fid, '# Segments are inclusive of the listed start time, but\n');
  fprintf(fid, '# exclusive of the listed stop time.\n');
  fprintf(fid, '# \n');
  fprintf(fid, '# start   stop      duration\n');
  fprintf(fid, '#-------- --------- --------\n');
end

% determine if data is floating point
isfloat = any(fix(start) ~= start) | any(fix(stop) ~= stop);

% write segments to file
if strcmp(format, 'two'),
  if isfloat,
    fprintf(fid, '%f %f\n', [start stop]');
  else
    fprintf(fid, '%9.9d %9.9d\n', [start stop]');  
  end
elseif strcmp(format, 'three') | strcmp(format, 'full'),
  if isfloat,
    fprintf(fid, '%f %f %f\n', [start stop duration]');
  else
    fprintf(fid, '%9.9d %9.9d %d\n', [start stop duration]');
  end
else
  error('unrecognized format');
end

% close output file
fclose(fid);

% return to calling function
return;
