function efficiency = sigmoid(amplitude, center, width, asymmetry, ...
                              pedestal, entablature)

%SIGMOID Compute asymmetric sigmoid efficiency curve.
%
%SYNOPSIS
%   EFFICIENCY = sigmoid(AMPLITUDE, CENTER, WIDTH, ASYMMETRY, ...
%                             PEDESTAL, ENTABLATURE)
%
%INPUTS
%   AMPLITUDE        vector of amplitudes
%   CENTER           approximate amplitude at fifty percent efficiency
%   WIDTH            approximate width of sigmoid curve in decades
%   ASYMMETRY        dimensionless asymmetry parameter
%   PEDESTAL         minimum efficiency in small amplitude limit
%   ENTABLATURE      maximum efficiency in large amplitude limit
%
%OUTPUTS
%   EFFICIENCY       vector of efficiencies at each amplitude
%
% Note that the center parameter is not the same as the amplitude at
% 50 percent detection efficiency unless the pedestal is zero, the
% entablature is unity, and the asymmetry is zero.  In general, the
% amplitude at 50 percent deteection efficiency can be determined by
% interpolation from the resulting sigmoid curve.  Perhaps there is an
% analytical expression for it, but it is has not been investigated.
% 
% See also SIGMOIDFIT and SIGMOIDCHISQUARE.
%
%AUTHOR
% Lindy L. Blackburn <lindy.blackburn@ligo.org>
% Shourov K. Chatterji (No longer in the LV Collaboration)

% $Id: sigmoid.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% dimensionless amplitude
amplitude = amplitude / center;

% transition rate
exponent = - (1 + asymmetry * tanh(amplitude)) / width;

% compute asymmetric sigmoid curve
efficiency = 1 ./ (1 + amplitude.^exponent);

% include minimum and maximum efficiency limits
efficiency = pedestal + (entablature - pedestal) * efficiency;
